@@ -8,7 +8,7 @@ from main.settings import BASE_DIR
 from xj_user.services.user_service import UserService
 from xj_user.services.user_sso_serve_service import UserSsoServeService
 from ..services.payment_wechat_service import PaymentWechatService
-# from ..services.payment_temporary_wechat_service import PaymentWechatService 为什么使用这个支付回调呢？？ 没有联动逻辑
+from ..services.payment_temporary_wechat_service import PaymentWechatService as temporary #为什么使用这个支付回调呢？？ 没有联动逻辑 答：支付已经整合 这个是为了刷单专门用的接口
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
 from ..utils.model_handle import parse_data, util_response
@@ -44,7 +44,7 @@ class PaymentWechat(APIView):
         sso_data = model_to_dict(sso_data)
         params = parse_data(self)
         params['openid'] = sso_data['sso_unicode']
-        wxpay_params = PaymentWechatService.payment_applets_pay(params)
+        wxpay_params = temporary.payment_applets_pay(params)
         return JsonResponse({
             'err': 0,
             'msg': 'OK',
