@@ -363,17 +363,19 @@ class PaymentWechatService:
             total_fee = param['total_fee']  # 金额（单位分）
             appid = param['appid']
             total_amount = int(total_fee) / 100  # 分转元
-            transaction_id = 0
+            transact_no = 0
             if 'transaction_id' in param:
-                transaction_id = param['transaction_id']  # 微信支付订单号
+                transact_no = param['transaction_id']  # 微信支付订单号
             finance_data = {
                 "order_no": out_trade_no,
-                "transact_id": transaction_id + "-1",
+                "transact_no": transact_no + "-1",
                 "their_account_name": sub_appid,
                 "platform": merchant_name,
                 "amount": float("-" + str(total_amount)),
                 "currency": "CNY",
                 "pay_mode": "WECHAT",
+                "finance_status_code": 2
+
             }
             # 根据订单号查询支付记录是否存在
             payment = PaymentPayment.objects.filter(order_no=int(out_trade_no)).first()
@@ -403,24 +405,25 @@ class PaymentWechatService:
             # 写入资金模块 （用户支付 (购买支出) ）
             funance_add_data, err_txt = FinanceTransactService.post(finance_data)
             if err_txt:
+                print(">>>>payment_logic_processing_err", err_txt)
                 logging.debug(">>>>payment_logic_processing" + "写入资金模块失败（用户支付）")
                 raise Networkerror("Bad hostname")
             # 根据唯一交易id 查询主键id
-            finance_data, err = FinanceTransactService.finance_transact_detailed(transaction_id + "-1")
+            finance_data, err = FinanceTransactService.finance_transact_detailed(transact_no + "-1")
             if finance_data:
                 finance_data = model_to_dict(finance_data)
                 payment_data = {
-                    "transact_no": transaction_id,
+                    "transact_no": transact_no,
                     "transact_id": finance_data['id'],
                     "payment_status": 1,
                     "pay_mode": "WECHAT",
-                    "order_status_id": "24"
+                    "order_status_id": 2
 
                 }
                 # （平台收入）
                 platform_revenue_data = {
                     "order_no": out_trade_no,
-                    "transact_id": transaction_id + "-2",
+                    "transact_no": transact_no + "-2",
                     "account_id": finance_data['their_account'],
                     "their_account_id": finance_data['account'],
                     "enroll_id": finance_data['enroll_id'],
@@ -430,9 +433,11 @@ class PaymentWechatService:
                         'full_name'] + "】项目名称【" + project_name + "】款项",
                     "currency": "CNY",
                     "pay_mode": "BALANCE",
+                    "finance_status_code": 2
                 }
                 finance_platform_data_set, finance_platform_err = FinanceTransactService.post(platform_revenue_data)
                 if finance_platform_err:
+                    print(">>>>payment_logic_processing_err", finance_platform_err)
                     logging.debug(">>>>payment_logic_processing" + "写入资金模块失败（平台收入）")
                     raise Networkerror("Bad hostname")
                 # 更改支付记录
