@@ -107,13 +107,14 @@ def my_ali_pay_v3():
 
 def applets_red_envelopes():
     url = "https://api.mch.weixin.qq.com/mmpaymkttransfers/sendminiprogramhb"
+    # path = '/mmpaymkttransfers/sendminiprogramhb'
     now = datetime.now()
     out_trade_no = '{0}{1}{2}'.format(sub_mch_id, now.strftime('%Y%m%d%H%M%S'), random.randint(1000, 10000))
     data = {
         'nonce_str': random_string(32),
         'mch_billno': out_trade_no,  # 商户订单号
-        'mch_id': sub_mch_id,  # 商户号
-        'wxappid': sub_appid,  # 公众账号appid
+        'mch_id': mch_id,  # 商户号
+        'wxappid': app_id,  # 公众账号appid
         'send_name': merchant_name,  # 商户名称
         're_openid': 'oj8KR5AR0sV20j96VBcnWulf7bbs',  # 用户openid
         'total_amount': 1,  # 付款金额
@@ -129,10 +130,13 @@ def applets_red_envelopes():
     amount = 1 / 100
     if amount >= 200:
         data['scene_id'] = 'PRODUCT_3'
-    wx_key = os.path.join(son_private_key_path)
-    wx_cert = os.path.join(son_cert_path)
+    wx_key = os.path.join(private_key_path)
+    wx_cert = os.path.join(cert_path)
+    response = requests.post(url=url, data=body.encode('utf-8'),
+                             cert=(wx_cert, wx_key))
+
     # response = requests.request("POST", url, headers=headers, data=body.encode("utf-8"))
-    response = requests.request("POST", url, data=body.encode('utf-8'), cert=(wx_cert, wx_key), verify=True)
+    # response = requests.request("POST", url, data=body.encode('utf-8'), cert=(wx_cert, wx_key), verify=True)
     return response.text
 
 
